## Data description

The **inputs** folder contains the following elements:

* **left.png and right.png :**  
Our data test sample is based on the 2003 Middleburry dataset (D. Scharstein & R. Szeliski, 2003).
(D. Scharstein & R. Szeliski, 2002). Scharstein, D., & Szeliski, R. (2002). A taxonomy and evaluation of dense two-frame stereo correspondence algorithms. International journal of computer vision, 47(1-3), 7-42.
(D. Scharstein & R. Szeliski, 2003). Scharstein, D., & Szeliski, R. (2003, June). High-accuracy stereo depth maps using structured light. In 2003 IEEE Computer Society Conference on Computer Vision and Pattern Recognition, 2003. Proceedings. (Vol. 1, pp. I-I). IEEE.

* **white_band_mask.png** 
Manually computed binary mask with strides for segmentation and classification for 3sgm optimization method tests. 

* **left_classif.tif and right_classif.tif** 
Manually computed 3 dimensions binary classification for 3sgm classification method tests.